@@ -110,6 +110,10 @@
             title: gettext('Public'),
             type: 'boolean'
           },
+          'hidden': {
+            title: gettext('Hidden'),
+            type: 'boolean'
+          },
           'registry_enabled': {
             title: gettext('Enable Registry'),
             type: 'boolean'
@@ -269,13 +273,15 @@
                     {
                       key: 'public'
                     },
+                    {
+                      key: 'hidden'
+                    },
                     {
                       key: 'registry_enabled'
                     },
                     {
                       key: 'tls_disabled'
                     }
-
                   ]
                 }
               ],
@@ -467,13 +473,14 @@
         coe: "",
         server_type: "",
         public: "",
+        hidden: "",
         registry_enabled: "",
         tls_disabled: "",
         image_id: "",
         flavor_id: "",
         master_flavor_id: "",
         docker_volume_size: "",
-        docker_storage_driver: "devicemapper",
+        docker_storage_driver: "",
         keypair_id: "",
         network_driver: "",
         volume_driver: "",
